com.blockether.vis.internal.gateway.cli

vis-agent gateway commands: start the daemon, report its status, pair a companion, stop it and run the terminal client under a gateway lease.

`vis-agent gateway` commands: start the daemon, report its status, pair a
companion, stop it and run the terminal client under a gateway lease.
raw docstring

commandclj

source

subcommandsclj

Subcommands registered under vis-agent gateway.

Subcommands registered under `vis-agent gateway`.
sourceraw docstring

web-commandclj

source

cljdoc builds & hosts documentation for Clojure/Script libraries