com.blockether.vis.internal.gateway.event-store

Process-local replay files retain locally assigned cursors, never shared-bus sequence numbers.

Process-local replay files retain locally assigned cursors, never shared-bus sequence numbers.
raw docstring

*max-bytes*clj

source

delete-event!clj

(delete-event! descriptor)
source

discard-replaced!clj

(discard-replaced! before after extra)

Delete retired files after the registry transition, never within a CAS retry.

Delete retired files after the registry transition, never within a CAS retry.
sourceraw docstring

lock-forclj

(lock-for sid)
source

read-eventclj

(read-event descriptor)
source

write-event!clj

(write-event! event)

Persist before publishing the descriptor. Failed writes declare a replay gap.

Persist before publishing the descriptor. Failed writes declare a replay gap.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries