com.blockether.vis.internal.content

Canonical role-labelled message and typed content-block contract.

This is the only persisted and transported answer shape. Maps use JSON-ready snake_case string keys so in-process and remote consumers observe identical values. Markdown exists only as the payload of a prose block.

Canonical role-labelled message and typed content-block contract.

This is the only persisted and transported answer shape. Maps use JSON-ready
snake_case string keys so in-process and remote consumers observe identical
values. Markdown exists only as the payload of a prose block.
raw docstring

answer-contentclj

(answer-content answer)

Convert the engine's final answer value into canonical blocks. Accepted answer values are Markdown strings, {:answer string}, and needs-input maps. Typed content vectors pass through after validation.

Convert the engine's final answer value into canonical blocks.
Accepted answer values are Markdown strings, `{:answer string}`, and
needs-input maps. Typed content vectors pass through after validation.
sourceraw docstring

assert-block!clj

(assert-block! block)
source

assert-message!clj

(assert-message! message)
source

attachmentclj

(attachment {:keys [id attachment-id name media-type] :or {id (block-id)}})
source

block-idclj

(block-id)
source

block-typesclj

source

block-valid?cljmultimethod

source

codeclj

(code text)
(code id text language)
source

errorclj

(error code message)
(error code message retryable?)
(error id code message retryable?)
source

event-valid?clj

(event-valid? event)
source

messageclj

(message
  {:keys [id role status content created-at completed-at model provider author]
   :or {status "streaming" content [] created-at (System/currentTimeMillis)}})
source

message-statusesclj

source

message-valid?clj

(message-valid? message)
source

noticeclj

(notice code message)
(notice id code message)
source

proseclj

(prose markdown)
(prose id markdown)
source

reasoningclj

(reasoning text)
(reasoning id text visibility)
source

reasoning-visibilitiesclj

source

rolesclj

source

text-projectionclj

(text-projection blocks)

Disposable plain-text projection for search, clipboard, and error fallback.

Disposable plain-text projection for search, clipboard, and error fallback.
sourceraw docstring

toolclj

(tool {:keys [id tool status input output error started-at completed-at]
       :or {id (block-id)}})
source

tool-statusesclj

source

cljdoc builds & hosts documentation for Clojure/Script libraries