com.blockether.vis.internal.council.host

Python host surface. Identity comes from the environment, never the mutable Python session dict.

Python host surface. Identity comes from the environment, never the mutable Python session dict.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries