Shared tiny string helpers. A dependency-free leaf so any namespace can use it without risking a cycle.
Shared tiny string helpers. A dependency-free leaf so any namespace can use it without risking a cycle.
(truncate s n)Head-clip s to at most n chars (no ellipsis).
Head-clip `s` to at most `n` chars (no ellipsis).
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |