Runtime TLS trust merged from a launcher-resolved PEM certificate bundle.
The native image and JVM both retain their configured default roots. A PEM
bundle discovered by bin/vis-agent is an additional trust source, which is
required on WSL because Windows and the Linux distribution have independent
certificate stores.
Runtime TLS trust merged from a launcher-resolved PEM certificate bundle. The native image and JVM both retain their configured default roots. A PEM bundle discovered by `bin/vis-agent` is an additional trust source, which is required on WSL because Windows and the Linux distribution have independent certificate stores.
(install!)(install! path)Install host trust once at startup, shared by HTTPS and pip. Never pass a session CA.
Install host trust once at startup, shared by HTTPS and pip. Never pass a session CA.
(ssl-context-for-pem path)Return the runtime-owned TLS context combining defaults and host PEM.
Return the runtime-owned TLS context combining defaults and host PEM.
(trust-manager-for-pem path)Return the runtime-owned trust manager combining defaults and host PEM.
Return the runtime-owned trust manager combining defaults and host PEM.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |